# Introduction 
Common functions to liveliness algorithms

# Getting Started

1. Install Python 3
2. Create virtual env (python3 -m venv .venv)
3. Activate virtual env (. ./.venv/bin/activate)
4. Install dependencies (pip install -U pip --no-cache && pip install -r requirements.txt)


